I have a Dream... of the Sphinx Boston, Massachusetts January 16th 2005 10 players Jon Scherer Deck Name: One, Two (As in "one, two princes stand before you, that's what I said now." Spin Doctors song.) So I think this proves that the Euro Brujah are strong even in the hands of someone who does not know what they are doing. The deck currently has too many votes and too much dominate. In this tournament it definitely needed more immortal grapple. People just kept running away. The flow of the deck is pretty poor as it is written. I may try more combat. I also could not get in as many fights as I would like so maybe a haven or additional bums rushes would be nice. Crypt (12 cards, min=16, max=32, avg=6.08) ------------------------------------------ 2x Constanza Vinti 8 CEL DOM POT prince Brujah:2 2x Dónal O'Connor 8 CEL DOM POT prince Brujah:2 2x Theo Bell 7 POT cel dom pre Brujah:2 2x Volker, The Puppet Prince 5 CEL pot prince Brujah:2 1x Anvil 6 CEL POT dom pre tha primogen Brujah:1 1x Jimmy Dunn 4 CEL POT for Pander:2 1x Victor Tolliver 4 CEL pot Brujah antitribu:2 1x Dre, Leader of the Cold Dawn 3 cel pot Brujah:1 Library (90 cards) Master (13) 4x Blood Doll 1x Carthage Remembered 1x Depravity 1x Direct Intervention 1x Dominate 1x Dreams of the Sphinx 1x Fame 1x Guardian Angel 1x Rack, The 1x Sudden Reversal Action (9) 4x Bum's Rush 5x Govern the Unaligned Equipment (1) 1x Ivory Bow Political Action (7) 1x Archon 1x Brujah Justicar 1x Conservative Agitation 3x Kine Resources Contested 1x Parity Shift Action Modifier (4) 3x Conditioning 1x Foreshadowing Destruction Reaction (14) 6x Deflection 6x Second Tradition: Domain 2x Wake with Evening's Freshness Combat (42) 5x Blur 1x Burning Wrath 3x Disarm 5x Flash 6x Immortal Grapple 6x Pursuit 1x Pushing the Limit 6x Sideslip 3x Taste of Vitae 6x Torn Signpost